@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Copyright [2015-2017] EMBL-European Bioinformatics Institute
+# Copyright [2015-2018] EMBL-European Bioinformatics Institute
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@ use File::Path qw(make_path);
 use Getopt::Long;
 
 my $htslib_version = "1.5";
+my $version = get_version();
 
 my $help = "INSTALL.pl [-h|--help] [--prefix=filepath] [--static] [~/prefix/path]\n";
 $help .= "--help (-h)  - this help message\n";
@@ -129,10 +130,10 @@ system "mv htslib-$htslib_version htslib" ;
 
 
 # STEP 3: Download Bio-DB-HTS
-info("Fetching latest version of Bio-DB-HTS from GitHub");
+info("Fetching version $version of Bio-DB-HTS from GitHub");
 chdir $install_dir;
-my $biodbhts_archive = "master.zip" ;
-my $biodbhts_archive_url = "https://github.com/Ensembl/Bio-DB-HTS/archive/master.zip" ;
+my $biodbhts_archive = "$version.zip" ;
+my $biodbhts_archive_url = "https://github.com/Ensembl/Bio-DB-HTS/archive/$version.zip" ;
 system "wget -O " . $biodbhts_archive . " " .$biodbhts_archive_url  ;
 if ( $? == -1 )
 {
@@ -140,7 +141,7 @@ if ( $? == -1 )
 }
 -f './'.$biodbhts_archive or die "Could not fetch Bio::DB::HTS archive ".$biodbhts_archive_url ;
 system "unzip ".$biodbhts_archive ;
-system "mv Bio-DB-HTS-master Bio-DB-HTS" ;
+system "mv Bio-DB-HTS-$version Bio-DB-HTS" ;
 -d './Bio-DB-HTS' or die "Unzip seems to have failed. Could not find $install_dir/Bio-DB-HTS directory";
 
 
@@ -179,39 +180,48 @@ info("Building Bio::DB::HTS");
 chdir "$install_dir/Bio-DB-HTS";
 my $cmd;
 if(defined $prefix_path) {
-  if(!$opts->{'static'}){
+  if(!$opts->{'static'}) {
     $cmd = "env HTSLIB_DIR=$prefix_path/lib perl Build.PL --install_base=$prefix_path";
-  }else{
+  } else {
     $cmd = "env HTSLIB_DIR=$install_dir/htslib perl Build.PL --install_base=$prefix_path";
   }
-}else{
+} else {
   $cmd = "env HTSLIB_DIR=$install_dir/htslib perl Build.PL";
 }
-if($opts->{'static'}){
+
+if($opts->{'static'}) {
   $cmd .= " --static=1";
 }
+
 warn "***CMD*** : $cmd\n";
 system $cmd;
+
 -e "./Build" or die "Build.PL didn't execute properly: no Build file found";
 system "./Build";
 `./Build test` =~ /Result: PASS/ or die "Build test failed. Not continuing";
 
 # Step 6: Install
+my $sudo = `which sudo`; chomp($sudo);
+
 if(defined $prefix_path) {
   info("Installing Bio::DB::HTS to $prefix_path.");
-  system "./Build install";
-}
-else {
+  `./Build install` =~ /Installing.+?HTS\.pm/ or die "Couldn't install to $prefix_path: $?";
+} elsif ($sudo) {
   info("Installing Bio::DB::HTS using sudo. You will be asked for your password.");
   info("If this step fails because sudo isn't installed, go back and run this script again as superuser.");
-  system "sudo ./Build install";
+  system "sudo ./Build install";;
+} else {
+  info("Installing Bio::DB::HTS system wide without sudo.");
+  info("Make sure you have the right privileges.");
+  `./Build install` =~ /Installing.+?HTS\.pm/ or die "Couldn't install at system level without sudo: $?";
 }
+
 if($opts->{'static'}){
   system "rm -f $install_dir/htslib/libhts.a";
 }
 
 # Step 7: Yay!
-info("Bio::DB::HTS is now installed.");
+info("Bio::DB::HTS v$version is now installed.");
 chdir '/';
 
 exit 0;
@@ -276,3 +286,16 @@ sub prefix_install {
   }
   return $prefix_path;
 }
+
+sub get_version {
+  use FindBin '$Bin';
+  my $version = `grep -m 1 "HTS::VERSION" $Bin/lib/Bio/DB/HTS.pm`;
+  $version =~ /(\d+?\.\d+?)\D/;
+  $version = $1;
+
+  use Carp;
+  croak "Couldn't get a meaningful library version: $version"
+    unless $version =~ /\d+?\.\d+?/;
+
+  return $version;
+}
